@@ -1,3 +1,32 @@
+/*
+  $Id: folia.cxx 13851 2012-01-03 08:48:59Z sloot $
+  $URL: https://ilk.uvt.nl/svn/sources/libfolia/trunk/src/folia.cxx $
+
+  Copyright (c) 1998 - 2012
+  ILK   - Tilburg University
+  CLiPS - University of Antwerp
+ 
+  This file is part of libfolia
+
+  libfolia is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  libfolia is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
+
+  For questions and suggestions, see:
+      http://ilk.uvt.nl/software.html
+  or send mail to:
+      timbl@uvt.nl
+*/
+
 #include <cstdlib>
 #include <iostream>
 #include <fstream>
