@@ -1,3 +1,32 @@
+/*
+  $Id: foliautils.cxx 13911 2012-01-09 11:33:39Z sloot $
+  $URL: https://ilk.uvt.nl/svn/sources/libfolia/trunk/src/foliautils.cxx $
+
+  Copyright (c) 1998 - 2012
+  ILK   - Tilburg University
+  CLiPS - University of Antwerp
+ 
+  This file is part of libfolia
+
+  libfolia is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  libfolia is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
+
+  For questions and suggestions, see:
+      http://ilk.uvt.nl/software.html
+  or send mail to:
+      timbl@uvt.nl
+*/
+
 #include <iostream>
 #include <sstream>
 #include <string>
@@ -467,22 +496,26 @@ namespace folia {
 
     for ( size_t i=0; i < s.size(); ++i ){
       //      cerr << "bekijk " << s[i] << endl;
-      //      cerr << "quoted = " << (quoted?"YES":"NO") << " parseatt = " << (parseatt?"YES":"NO") << endl;
+      //      cerr << "quoted = " << (quoted?"YES":"NO") 
+      // 	   << " parseatt = " << (parseatt?"YES":"NO")
+      // 	   << " escaped = " << (escaped?"YES":"NO") << endl;
       if ( s[i] == '\\' ){
-	//	cerr << "found a \\" << endl;
-	if ( i < s.size()-1 ){
-	  if ( s[i+1] == '\\' ){
-	    // escaped backslash
-	    continue;
+	//	cerr << "handle backslash " << endl;
+	if ( quoted ){
+	  if ( escaped ){
+	    val += s[i];
+	    escaped = false;
 	  }
-	  if ( s[i+1] == '\'' ){
-	    // escaped '
+	  else {
 	    escaped = true;
 	    continue;
 	  }
 	}
+	else
+	  throw ArgsError( s + ", stray \\" );	  
       }
-      if ( s[i] == '\'' ){
+      else if ( s[i] == '\'' ){
+	//	cerr << "handle single quote " << endl;
 	if ( quoted ){
 	  if ( escaped ){
 	    val += s[i];
@@ -526,12 +559,17 @@ namespace folia {
       }
       else if ( parseatt )
 	att += s[i];
-      else if ( quoted )
+      else if ( quoted ){
+	if ( escaped ){
+	  val += "\\";
+	  escaped = false;
+	}
 	val += s[i];
+      }
       else
-	throw ArgsError( s + ", unquoted value?" );
-      //      cerr << "att = '" << att << "'" << endl;
-      //      cerr << "val = '" << val << "'" << endl;
+	throw ArgsError( s + ", unquoted value or missing , ?" );
+      // cerr << "att = '" << att << "'" << endl;
+      // cerr << "val = '" << val << "'" << endl;
     }
     if ( quoted )
       throw ArgsError( s + ", unbalanced '?" );
